"""Testing formula 8.9 of EN 1992-1-1:2004."""

import pytest

from blueprints.codes.eurocode.en_1992_1_1_2004.chapter_8_detailing_of_reinforcement_and_prestressing_tendons.formula_8_9 import (
    Form8Dot9AnchorageCapacityWeldedTransverseBarSmallDiameter,
)
from blueprints.validations import LessOrEqualToZeroError, NegativeValueError


class TestForm8Dot9AnchorageCapacityWeldedTransverseBarSmallDiameter:
    """Validation for formula 8.9 from EN 1992-1-1:2004."""

    def test_evaluation(self) -> None:
        """Test the evaluation of the result."""
        # example values
        f_wd = 15  # kN
        diameter_t = 8  # mm
        diameter_l = 10  # mm
        a_s = 78.5  # mm²
        f_cd = 20  # MPa
        form_8_9 = Form8Dot9AnchorageCapacityWeldedTransverseBarSmallDiameter(
            f_wd=f_wd,
            diameter_t=diameter_t,
            diameter_l=diameter_l,
            a_s=a_s,
            f_cd=f_cd,
        )

        manually_calculated_result = 15  # kN

        assert form_8_9 == pytest.approx(expected=manually_calculated_result, rel=1e-4)

    def test_evaluation_upper_limit(self) -> None:
        """Test the evaluation of the result if the upper limit is reached."""
        # example values
        # example values
        f_wd = 25  # kN
        diameter_t = 8  # mm
        diameter_l = 10  # mm
        a_s = 78.5  # mm²
        f_cd = 20  # MPa
        form_8_9 = Form8Dot9AnchorageCapacityWeldedTransverseBarSmallDiameter(
            f_wd=f_wd,
            diameter_t=diameter_t,
            diameter_l=diameter_l,
            a_s=a_s,
            f_cd=f_cd,
        )

        manually_calculated_result = 20.096  # kN

        assert form_8_9 == pytest.approx(expected=manually_calculated_result, rel=1e-4)

    def test_if_error_is_raised_for_negative_f_wd(self) -> None:
        """Test if the correct error is raised for a negative f_wd."""
        # example values
        f_wd = -15  # kN
        diameter_t = 8  # mm
        diameter_l = 10  # mm
        a_s = 78.5  # mm²
        f_cd = 20  # MPa

        with pytest.raises(NegativeValueError):
            Form8Dot9AnchorageCapacityWeldedTransverseBarSmallDiameter(
                f_wd=f_wd,
                diameter_t=diameter_t,
                diameter_l=diameter_l,
                a_s=a_s,
                f_cd=f_cd,
            )

    def test_if_error_is_raised_for_negative_diameter_t(self) -> None:
        """Test if the correct error is raised for a negative diameter_t."""
        # example values
        f_wd = 15  # kN
        diameter_t = -8  # mm
        diameter_l = 10  # mm
        a_s = 78.5  # mm²
        f_cd = 20  # MPa

        with pytest.raises(NegativeValueError):
            Form8Dot9AnchorageCapacityWeldedTransverseBarSmallDiameter(
                f_wd=f_wd,
                diameter_t=diameter_t,
                diameter_l=diameter_l,
                a_s=a_s,
                f_cd=f_cd,
            )

    def test_if_error_is_raised_for_negative_diameter_l(self) -> None:
        """Test if the correct error is raised for a negative diameter_l."""
        # example values
        f_wd = 15  # kN
        diameter_t = 8  # mm
        diameter_l = -10  # mm
        a_s = 78.5  # mm²
        f_cd = 20  # MPa

        with pytest.raises(LessOrEqualToZeroError):
            Form8Dot9AnchorageCapacityWeldedTransverseBarSmallDiameter(
                f_wd=f_wd,
                diameter_t=diameter_t,
                diameter_l=diameter_l,
                a_s=a_s,
                f_cd=f_cd,
            )

    def test_if_error_is_raised_for_zero_diameter_l(self) -> None:
        """Test if the correct error is raised for a zero diameter_l."""
        # example values
        f_wd = 15  # kN
        diameter_t = 8  # mm
        diameter_l = 0  # mm
        a_s = 78.5  # mm²
        f_cd = 20  # MPa

        with pytest.raises(LessOrEqualToZeroError):
            Form8Dot9AnchorageCapacityWeldedTransverseBarSmallDiameter(
                f_wd=f_wd,
                diameter_t=diameter_t,
                diameter_l=diameter_l,
                a_s=a_s,
                f_cd=f_cd,
            )

    def test_if_error_is_raised_for_negative_a_s(self) -> None:
        """Test if the correct error is raised for a negative a_s."""
        # example values
        f_wd = 15  # kN
        diameter_t = 8  # mm
        diameter_l = 10  # mm
        a_s = -78.5  # mm²
        f_cd = 20  # MPa

        with pytest.raises(NegativeValueError):
            Form8Dot9AnchorageCapacityWeldedTransverseBarSmallDiameter(
                f_wd=f_wd,
                diameter_t=diameter_t,
                diameter_l=diameter_l,
                a_s=a_s,
                f_cd=f_cd,
            )

    def test_if_error_is_raised_for_negative_f_cd(self) -> None:
        """Test if the correct error is raised for a negative f_cd."""
        # example values
        f_wd = 15  # kN
        diameter_t = 8  # mm
        diameter_l = 10  # mm
        a_s = 78.5  # mm²
        f_cd = -20  # MPa

        with pytest.raises(NegativeValueError):
            Form8Dot9AnchorageCapacityWeldedTransverseBarSmallDiameter(
                f_wd=f_wd,
                diameter_t=diameter_t,
                diameter_l=diameter_l,
                a_s=a_s,
                f_cd=f_cd,
            )

    @pytest.mark.parametrize(
        ("representation", "expected"),
        [
            (
                "complete",
                (
                    r"F_{btd} = \min \left( F_{wd}, 16 \cdot A_s \cdot f_{cd} \cdot \frac{Ø_t}{Ø_l} \right) = "
                    r"\min \left( 15.00, 1000 \cdot 16 \cdot 78.50 \cdot 20.00 \cdot \frac{8.00}{10.00} \right) = 15.00"
                ),
            ),
            ("short", r"F_{btd} = 15.00"),
        ],
    )
    def test_latex(self, representation: str, expected: str) -> None:
        """Test the latex representation of the formula."""
        # example values
        f_wd = 15  # kN
        diameter_t = 8  # mm
        diameter_l = 10  # mm
        a_s = 78.5  # mm²
        f_cd = 20  # MPa

        # Object to test
        form_8_9_latex = Form8Dot9AnchorageCapacityWeldedTransverseBarSmallDiameter(
            f_wd=f_wd,
            diameter_t=diameter_t,
            diameter_l=diameter_l,
            a_s=a_s,
            f_cd=f_cd,
        ).latex()

        actual = {"complete": form_8_9_latex.complete, "short": form_8_9_latex.short}

        assert actual[representation] == expected, f"{representation} representation failed."



"""Formula 12.1 from EN 1992-1-1:2004: Chapter 12 - Plain and Lightly Reinforced Concrete Structures."""

from blueprints.codes.eurocode.en_1992_1_1_2004 import EN_1992_1_1_2004
from blueprints.codes.formula import Formula
from blueprints.codes.latex_formula import LatexFormula
from blueprints.type_alias import DIMENSIONLESS, MPA
from blueprints.validations import raise_if_less_or_equal_to_zero, raise_if_negative


class Form12Dot1PlainConcreteTensileStrength(Formula):
    r"""Class representing formula 12.1 for the calculation of the design tensile strength of plain concrete,
    :math:`f_{ctd,pl}`.

    EN 1992-1-1:2004 art.12.3.1(2) - Formula (12.1)
    """

    label = "12.1"
    source_document = EN_1992_1_1_2004

    def __init__(
        self,
        alpha_ct: DIMENSIONLESS,
        f_ctk_0_05: MPA,
        gamma_c: DIMENSIONLESS,
    ) -> None:
        r"""[:math:`f_{ctd,pl}`] Design tensile strength of plain concrete [:math:`MPa`].

        EN 1992-1-1:2004 art.12.3.1(2) - Formula (12.1)

        Parameters
        ----------
        alpha_ct : DIMENSIONLESS
            [:math:`\\alpha_{ct,pl}`] Reduction factor for plain concrete [-].
        f_ctk_0_05 : MPa
            [:math:`f_{ctk,0.05}`] Characteristic tensile strength of concrete [:math:`MPa`].
        gamma_c : DIMENSIONLESS
            [:math:`\\gamma_{C}`] Partial safety factor for concrete [-].
        """
        super().__init__()
        self.alpha_ct = alpha_ct
        self.f_ctk_0_05 = f_ctk_0_05
        self.gamma_c = gamma_c

    @staticmethod
    def _evaluate(
        alpha_ct: DIMENSIONLESS,
        f_ctk_0_05: MPA,
        gamma_c: DIMENSIONLESS,
    ) -> MPA:
        """Evaluates the formula, for more information see the __init__ method."""
        raise_if_negative(
            alpha_ct_pl=alpha_ct,
            f_ctk_0_05=f_ctk_0_05,
        )
        raise_if_less_or_equal_to_zero(gamma_c=gamma_c)
        return alpha_ct * f_ctk_0_05 / gamma_c

    def latex(self, n: int = 3) -> LatexFormula:
        """Returns LatexFormula object for formula 12.1."""
        return LatexFormula(
            return_symbol=r"f_{ctd,pl}",
            result=f"{self:.{n}f}",
            equation=r"\alpha_{ct,pl} \cdot \frac{f_{ctk,0.05}}{\gamma_{C}}",
            numeric_equation=rf"{self.alpha_ct:.{n}f} \cdot \frac{{{self.f_ctk_0_05:.{n}f}}}{{{self.gamma_c:.{n}f}}}",
            comparison_operator_label="=",
        )



"""Formula 5.7a and 5.7b from EN 1992-1-1:2004: Chapter 5 - Structural Analysis."""

from blueprints.codes.eurocode.en_1992_1_1_2004 import EN_1992_1_1_2004
from blueprints.codes.formula import Formula
from blueprints.codes.latex_formula import LatexFormula
from blueprints.type_alias import M
from blueprints.validations import raise_if_negative


class Form5Dot7abFlangeEffectiveFlangeWidth(Formula):
    """Class representing formula 5.7a and formula 5.7b for the calculation of effective flange width of the i-th flange [$b_{eff,i}$].
    See Figure 5.3.
    """

    label = "5.7a, 5.7b"
    source_document = EN_1992_1_1_2004

    def __init__(
        self,
        b_i: M,
        l_0: M,
    ) -> None:
        r"""[$b_{eff,i}$] Effective flange width of the i-th flange of a beam [$m$].

        EN 1992-1-1:2004 art.5.3.2.1(3) - Formula (5.7a) and (5.7b)

        Parameters
        ----------
        b_i : M
            [$b_{i}$] Effective flange width of the i-th flange [$m$].
        l_0 : M
            [$l_{0}$] distance between points of zero moment, which may be obtained from Figure 5.2 [$m$].

        Notes
        -----
        This formula is the combination of formula 5.7a and 5.7b. Formula 5.7a and 5.7b cannot be used independently.
        """
        super().__init__()
        self.b_i = b_i
        self.l_0 = l_0

    @staticmethod
    def _evaluate(
        b_i: M,
        l_0: M,
    ) -> M:
        """Evaluates the formula, for more information see the __init__ method."""
        raise_if_negative(
            b_i=b_i,
            l_0=l_0,
        )
        return min(0.2 * b_i + 0.1 * l_0, 0.2 * l_0, b_i)

    def latex(self, n: int = 3) -> LatexFormula:
        """Returns LatexFormula object for formula 5.7ab."""
        return LatexFormula(
            return_symbol=r"b_{eff,i}",
            result=f"{self:.{n}f}",
            equation=r"0.2b_{i}+0.1l_{0} \le 0.2l_{0}\text{ and }b_{eff,i}\le b_{i}",
            numeric_equation=rf"0.2\cdot{self.b_i}+0.1\cdot{self.l_0} \le 0.2\cdot{self.l_0}\text{{ and }}b_{{eff,i}}\le {self.b_i}",
            comparison_operator_label="=",
        )



"""Formula 9.14 from EN 1992-1-1:2004: Chapter 9 - Detailing and specific rules."""

from blueprints.codes.eurocode.en_1992_1_1_2004 import EN_1992_1_1_2004
from blueprints.codes.formula import Formula
from blueprints.codes.latex_formula import LatexFormula
from blueprints.type_alias import KN, MM
from blueprints.validations import raise_if_negative


class Form9Dot14SplittingForceColumnOnRock(Formula):
    """Class representing the formula 9.14 for the calculation of the splitting force on a column footing on rock."""

    label = "9.14"
    source_document = EN_1992_1_1_2004

    def __init__(
        self,
        c: MM,
        h: MM,
        n_ed: KN,
    ) -> None:
        r"""[$F_s$] Splitting force on a column footing on rock [$kN$].

        EN 1992-1-1:2004 art.9.8.4(2) - Formula (9.14)

        Parameters
        ----------
        c: MM
            [$c$] Width over which [$N_{Ed}$] is applied [$mm$].
        h: MM
            [$h$] Lesser of [$b$] and [$H$] from figure 9.14 [$mm$].
        n_ed: KN
            [$N_{Ed}$] Design value of the applied axial force [$kN$].
        """
        super().__init__()
        self.c = c
        self.h = h
        self.n_ed = n_ed

    @staticmethod
    def _evaluate(
        c: MM,
        h: MM,
        n_ed: KN,
    ) -> KN:
        """For more detailed documentation see the class docstring."""
        raise_if_negative(c=c, h=h, n_ed=n_ed)
        return 0.25 * (1 - (c / h)) * n_ed

    def latex(self, n: int = 2) -> LatexFormula:
        """Returns LatexFormula object for formula 9.14."""
        return LatexFormula(
            return_symbol=r"F_s",
            result=f"{self:.{n}f}",
            equation=r"0.25 \cdot ( 1 - c / h ) \cdot N_{Ed}",
            numeric_equation=rf"0.25 \cdot ( 1 - {self.c:.{n}f} / {self.h:.{n}f} ) \cdot {self.n_ed:.{n}f}",
            comparison_operator_label="=",
        )



"""Testing formula 5.33 of EN 1992-1-1:2004."""

import pytest

from blueprints.codes.eurocode.en_1992_1_1_2004.chapter_5_structural_analysis.formula_5_33 import Form5Dot33NominalSecondOrderMoment
from blueprints.validations import LessOrEqualToZeroError, NegativeValueError


class TestForm5Dot33NominalSecondOrderMoment:
    """Validation for formula 5.33 from EN 1992-1-1:2004."""

    def test_evaluation(self) -> None:
        """Tests the evaluation of the result."""
        # Example values
        n_ed = 100.0
        curvature = 0.01
        l_o = 5.0
        c = 10.0

        # Object to test
        formula = Form5Dot33NominalSecondOrderMoment(n_ed=n_ed, curvature=curvature, l_o=l_o, c=c)

        # Expected result, manually calculated
        manually_calculated_result = 2.5  # kNm

        assert formula == pytest.approx(expected=manually_calculated_result, rel=1e-4)

    @pytest.mark.parametrize(
        ("n_ed", "curvature", "l_o", "c"),
        [
            (-100.0, 0.01, 5.0, 10.0),  # n_ed is negative
            (100.0, -0.01, 5.0, 10.0),  # curvature is negative
            (100.0, 0.01, -5.0, 10.0),  # l_o is negative
            (100.0, 0.01, 5.0, -10.0),  # c is negative
            (0.0, 0.01, 5.0, 10.0),  # n_ed is zero
            (100.0, 0.0, 5.0, 10.0),  # curvature is zero
            (100.0, 0.01, 0.0, 10.0),  # l_o is zero
            (100.0, 0.01, 5.0, 0.0),  # c is zero
        ],
    )
    def test_raise_error_when_invalid_values_are_given(self, n_ed: float, curvature: float, l_o: float, c: float) -> None:
        """Test invalid values."""
        with pytest.raises((NegativeValueError, LessOrEqualToZeroError)):
            Form5Dot33NominalSecondOrderMoment(n_ed=n_ed, curvature=curvature, l_o=l_o, c=c)

    @pytest.mark.parametrize(
        ("representation", "expected"),
        [
            (
                "complete",
                r"M_{2} = N_{Ed} \cdot \left(\frac{1}{r}\right) \cdot \frac{l_{o}^2}{c} "
                r"= 100.000 \cdot \left(0.010\right) \cdot \frac{5.000^2}{10.000} = 2.500 \ kNm",
            ),
            ("short", r"M_{2} = 2.500 \ kNm"),
        ],
    )
    def test_latex(self, representation: str, expected: str) -> None:
        """Test the latex representation of the formula."""
        # Example values
        n_ed = 100.0
        curvature = 0.01
        l_o = 5.0
        c = 10

        # Object to test
        latex = Form5Dot33NominalSecondOrderMoment(n_ed=n_ed, curvature=curvature, l_o=l_o, c=c).latex()

        actual = {
            "complete": latex.complete,
            "short": latex.short,
        }

        assert expected == actual[representation], f"{representation} representation failed."



"""Testing formula 5.43 of EN 1992-1-1:2004."""

import pytest

from blueprints.codes.eurocode.en_1992_1_1_2004.chapter_5_structural_analysis.formula_5_43 import Form5Dot43InitialPrestressForce
from blueprints.validations import LessOrEqualToZeroError, NegativeValueError


class TestForm5Dot43InitialPrestressForce:
    """Validation for formula 5.43 from EN 1992-1-1:2004."""

    def test_evaluation(self) -> None:
        """Tests the evaluation of the result."""
        # Example values
        a_p = 1000.0  # mm^2
        k_7 = 0.75  # -
        f_pk = 1860.0  # MPa
        k_8 = 0.85  # -
        f_p0_1k = 1674.0  # MPa

        # Object to test
        formula = Form5Dot43InitialPrestressForce(a_p=a_p, k_7=k_7, f_pk=f_pk, k_8=k_8, f_p0_1k=f_p0_1k)

        # Expected result, manually calculated
        manually_calculated_result = 1395000.0  # N

        assert formula == pytest.approx(manually_calculated_result, rel=1e-4)

    @pytest.mark.parametrize(
        ("a_p", "k_7", "f_pk", "k_8", "f_p0_1k"),
        [
            (-1000.0, 0.75, 1860.0, 0.85, 1674.0),  # a_p is negative
            (1000.0, -0.75, 1860.0, 0.85, 1674.0),  # k_7 is negative
            (1000.0, 0.75, -1860.0, 0.85, 1674.0),  # f_pk is negative
            (1000.0, 0.75, 1860.0, -0.85, 1674.0),  # k_8 is negative
            (1000.0, 0.75, 1860.0, 0.85, -1674.0),  # f_p0_1k is negative
        ],
    )
    def test_raise_error_when_invalid_values_are_given(self, a_p: float, k_7: float, f_pk: float, k_8: float, f_p0_1k: float) -> None:
        """Test invalid values."""
        with pytest.raises((NegativeValueError, LessOrEqualToZeroError)):
            Form5Dot43InitialPrestressForce(a_p=a_p, k_7=k_7, f_pk=f_pk, k_8=k_8, f_p0_1k=f_p0_1k)

    @pytest.mark.parametrize(
        ("representation", "expected"),
        [
            (
                "complete",
                r"P_{m0}(x) = A_{p} \cdot \min \left(k_7 \cdot f_{pk} ; k_8 \cdot f_{p0.1k} \right) = "
                r"1000.000 \cdot \min \left(0.750 \cdot 1860.000 ; 0.850 \cdot 1674.000 \right) = 1395000.000 \ N",
            ),
            ("short", r"P_{m0}(x) = 1395000.000 \ N"),
        ],
    )
    def test_latex(self, representation: str, expected: str) -> None:
        """Test the latex representation of the formula."""
        # Example values
        a_p = 1000.0  # mm^2
        k_7 = 0.75  # -
        f_pk = 1860.0  # MPa
        k_8 = 0.85  # -
        f_p0_1k = 1674.0  # MPa

        # Object to test
        latex = Form5Dot43InitialPrestressForce(a_p=a_p, k_7=k_7, f_pk=f_pk, k_8=k_8, f_p0_1k=f_p0_1k).latex()

        actual = {
            "complete": latex.complete,
            "short": latex.short,
        }

        assert expected == actual[representation], f"{representation} representation failed."



"""Testing sub-formula 8.16 (α1) of EN 1992-1-1:2004."""

import pytest

from blueprints.codes.eurocode.en_1992_1_1_2004.chapter_8_detailing_of_reinforcement_and_prestressing_tendons.formula_8_16 import (
    SubForm8Dot16Alpha1,
)


class TestSubForm8Dot16Alpha1:
    """Validation for sub-formula 8.16 (α1) from EN 1992-1-1:2004."""

    def test_evaluation_gradual(self) -> None:
        """Test the evaluation of the result when release_type is gradual."""
        # example values
        release_type = "gradual"

        sub_form_8_16_alpha_1 = SubForm8Dot16Alpha1(release_type=release_type)

        # manually calculated result
        manually_calculated_result = 1  # [-]

        assert sub_form_8_16_alpha_1 == pytest.approx(expected=manually_calculated_result, rel=1e-4)

    def test_evaluation_sudden(self) -> None:
        """Test the evaluation of the result when release_type is sudden."""
        # example values
        release_type = "sudden"

        sub_form_8_16_alpha_1 = SubForm8Dot16Alpha1(release_type=release_type)

        # manually calculated result
        manually_calculated_result = 1.25

        assert sub_form_8_16_alpha_1 == pytest.approx(expected=manually_calculated_result, rel=1e-4)

    def test_raise_error_if_invalid_release_type(self) -> None:
        """Test that a ValueError is raised when an invalid value is passed for release_type."""
        release_type = "invalid"

        with pytest.raises(ValueError):
            SubForm8Dot16Alpha1(release_type=release_type)

    @pytest.mark.parametrize(
        ("representation", "expected"),
        [
            (
                "complete",
                (r"\alpha_1 \rightarrow release\;type \rightarrow gradual \rightarrow 1.00"),
            ),
            ("short", r"\alpha_1 \rightarrow 1.00"),
        ],
    )
    def test_latex(self, representation: str, expected: str) -> None:
        """Test the latex representation of the formula."""
        # example values
        release_type = "gradual"

        # Object to test
        form_8_16_p1_latex = SubForm8Dot16Alpha1(release_type=release_type).latex()

        actual = {"complete": form_8_16_p1_latex.complete, "short": form_8_16_p1_latex.short}

        assert actual[representation] == expected, f"{representation} representation failed."



"""Testing formula 8.5 of EN 1992-1-1:2004."""

import pytest

from blueprints.codes.eurocode.en_1992_1_1_2004.chapter_8_detailing_of_reinforcement_and_prestressing_tendons.formula_8_5 import (
    Form8Dot5ProductAlphas235,
)
from blueprints.validations import NegativeValueError


class TestForm8Dot4DesignAnchorageLength:
    """Validation for formula 8.5 from EN 1992-1-1:2004."""

    def test_evaluation(self) -> None:
        """Test the evaluation of the result."""
        # example values
        alpha_2 = 0.8  # [-]
        alpha_3 = 0.9  # [-]
        alpha_5 = 1  # [-]
        form_8_4 = Form8Dot5ProductAlphas235(
            alpha_2=alpha_2,
            alpha_3=alpha_3,
            alpha_5=alpha_5,
        )

        # manually calculated result
        manually_calculated_result = 0.72  # mm

        assert form_8_4 == pytest.approx(expected=manually_calculated_result, rel=1e-4)

    def test_evaluation_below_minimum(self) -> None:
        """Test the evaluation of the result if the minimum is reached."""
        # example values
        alpha_2 = 0.6  # [-]
        alpha_3 = 1  # [-]
        alpha_5 = 1  # [-]
        form_8_4 = Form8Dot5ProductAlphas235(
            alpha_2=alpha_2,
            alpha_3=alpha_3,
            alpha_5=alpha_5,
        )

        # manually calculated result
        manually_calculated_result = 0.7  # mm

        assert form_8_4 == pytest.approx(expected=manually_calculated_result, rel=1e-4)

    @pytest.mark.parametrize(
        ("alpha_2", "alpha_3", "alpha_5"),
        [
            (-1, 1, 1),  # alpha_2 is negative
            (1, -1, 1),  # alpha_3 is negative
            (1, 1, -1),  # alpha_5 is negative
        ],
    )
    def test_negative_alpha(self, alpha_2: float, alpha_3: float, alpha_5: float) -> None:
        """Test the evaluation of the result if one of the alpha values is negative."""
        with pytest.raises(NegativeValueError):
            Form8Dot5ProductAlphas235(
                alpha_2=alpha_2,
                alpha_3=alpha_3,
                alpha_5=alpha_5,
            )

    @pytest.mark.parametrize(
        ("representation", "expected_result"),
        [
            ("complete", r"\alpha_2 \cdot \alpha_3 \cdot \alpha_5 \ge 0.7 \to 1 \cdot 1 \cdot 1 \ge 0.7 \to 1.00"),
            ("short", " \\to 1.00"),
        ],
    )
    def test_latex(self, representation: str, expected_result: str) -> None:
        """Test latex representation of the formula."""
        alpha_2 = 1  # [-]
        alpha_3 = 1  # [-]
        alpha_5 = 1  # [-]
        latex = Form8Dot5ProductAlphas235(
            alpha_2=alpha_2,
            alpha_3=alpha_3,
            alpha_5=alpha_5,
        ).latex()

        actual = {
            "complete": latex.complete,
            "short": latex.short,
        }

        assert actual[representation] == expected_result, f"{representation} representation failed."
